import React, { Component } from 'react';
import {findDOMNode} from 'react-dom';
import TagInput from 'recruit-tag-input';
import DropList from './dropList';
import CommonMount from '@beisen-platform/ethos/lib/CommonMount';
import BaseButton from '@beisen-platform/ethos/lib/BaseButton';
import CommonPop from '@beisen-platform/ethos/lib/CommonPop';
import CreatePage from './createPage';
import './index.scss';

export default class extends Component {
	constructor(props) {
		super(props);
		this.state = {
			popShow: props.showPop == undefined ? false : props.showPop
			,children: props.children && props.children.length>0 ? props.children : []
			,defaultItems: props.defaultItems && props.defaultItems.length>0 ? props.defaultItems : []
	    	,isEmailError: false
	    	,keepActive: false
		}
		this.CommonMount = new CommonMount({
			containerId: 'DropdownList_ul', // 容器ID
			follow: true, // 是否滚动跟随，默认true
			fixed: true // 定位：fixed，false时为absolute
		});

		this.onClose = this.onClose.bind(this);
		this.handleClick = this.handleClick.bind(this);
		this.createUserItem = this.createUserItem.bind(this);
		this.submitPop = this.submitPop.bind(this);
		this.closePop = this.closePop.bind(this);
	}

	componentWillReceiveProps(nextProps) {
		if (nextProps.children !== this.props.children) {
			this.setState({children: nextProps.children});
		}
		if (nextProps.defaultItems !== this.props.defaultItems) {
			this.setState({defaultItems: nextProps.defaultItems});
		}
		if (nextProps.isEmailError !== this.props.isEmailError) {
			this.setState({isEmailError: nextProps.isEmailError});
		}
		if (nextProps.showPop !== this.props.showPop) {
			this.setState({popShow: nextProps.showPop});
		}
	}

	componentDidUpdate() {
		let dom = document.getElementsByClassName('tag-input-is-active')[0];
		if(dom && this.props.autoShowPanel && this.state.keepActive) { this.renderDom(dom.parentNode); };
	}

	addItems(event, val) {
		const { single } = this.props;
		let duplicate = [];
		this.state.defaultItems.forEach(item => {
			if (val.value == item.value) duplicate.push(item)
		});
		if (duplicate.length > 0) return false;
		const item = {
			text: val.text[0] + (val.text[1] ? ('(' + val.text[1] + ')') : '')
			,value: val.value
		}
		if ( single || single==undefined ) {
			this.state.defaultItems = [item];
		} else {
			let defaultItems = [...this.state.defaultItems];
			defaultItems.push(item);
			this.state.defaultItems = defaultItems;
		}
		this.setState(this.state);
		this.props.onSureClick && this.props.onSureClick(event, this.state.defaultItems);
	}

	renderDom(tar) {
		const self = this;
		const dropdownDate = {
			limitCount: 10,
			multiple: true,
			children: this.state.children,
			dropdownWidth:  tar.offsetWidth,
			hasSearch: false,
			itemClick: function(event, val) {
				self.state.keepActive = false;
				self.CommonMount.unmountBox();
				self.addItems(event, val);
			}
		}
		let dropHeight;
		let dropcount = this.props.children.length>10 ? 10 : this.props.children.length;
		dropHeight = this.props.children.length > 10 ? 280 : (dropcount * 28);
		const showAutoUl = <DropList {...dropdownDate} />
		this.CommonMount.renderDom(
			'mount-box-dropdownlist', // wrap's classname & id
			showAutoUl, // content dom
			tar, // 跟随目标
			[
				tar, //挂载目标节点
				{ // 挂载元素宽高 {width: '', height: ''}
					width:  tar.clientWidth,// 挂载宽度
					height: dropHeight
				}
				,28
			],
			true, //labeL和input框是否为竖向结构，会留出对应的label空间
      		0, //水平向左偏移量，为负数则向右
			false, //弹层靠左靠右模式，默认为false 靠左模式
			100, //window.onresize执行时间，默认100ms
			false,  //输入框高度
			999999999   //自定义zindex
		);
	}

	onClose(event) {
		try {
			findDOMNode(this);
		} catch(e) {
			this.CommonMount.unmountBox();
			this.setState({keepActive: false})
			document.removeEventListener('mousedown', this.onClose);
			this.props.onClose && this.props.onClose("close");
			return;
		}

		let area = document.getElementById("DropdownList_ul");
		if (area && !area.contains(event.target)) {
			// if (event.target.className.indexOf('sys-icon-close')>-1|| event.target.className.indexOf('u-icon')>-1 || event.target.tagName === 'BODY') return;
			this.CommonMount.unmountBox();
			this.setState({keepActive: false})
			document.removeEventListener('mousedown', this.onClose);
			this.props.onClose && this.props.onClose("close");
		}
	}

	handleClick(event, value) {
		let dom = event.target.parentNode.parentNode.parentNode;
		this.renderDom(dom);
		this.setState({keepActive: true});
		document.removeEventListener('mousedown', this.onClose);
  		document.addEventListener('mousedown', this.onClose);
  		this.props.inputOnClick && this.props.inputOnClick(event, value)
	}

	handleDelete(event, value) {
		this.props.onDeleteItem && this.props.onDeleteItem(event, value);
	}

	createUserItem() {
		this.setState({popShow: true});
	}

	submitPop() {
		this.refs.createPage.validateAll();
		const { nameValue, emailValue, phoneValue, nameRequired, emailRequired, wrongEmail, wrongPhone } = this.refs.createPage.state;
		if (wrongEmail || wrongPhone || nameValue == '' || emailValue == '') {return false}
		this.props.throwCreateData && this.props.throwCreateData({
			name: nameValue
			,email: emailValue
			,phone: phoneValue
		})
		if (this.props.showPop) return false;
		this.closePop();
	}

	closePop() {
		this.setState({popShow: false})
	}

	render() {
		const self = this;
		const { maxCount, onSearch, title, isRequired, lablePos, lableText, 
				errorStatus, errorMessage, disableKeyDown, canCreate, 
				disableInput, createBtnText, isEmailError, emailErrorTip, validateEmail  } = this.props;
		let btnOpt1 = {
        	bsStyle: "weaken",
        	bsSize: "default",
        	title: "取消" /**显示文本(string)**/ ,
        	onClick: function(target,onClick,btnInfo) {self.closePop()} /**点击后事件回调**/
      	}
      	let btnOpt2 = {
        	bsStyle: "default",
        	bsSize: "default",
        	title: "确定" /**显示文本(string)**/ ,
        	onClick: function(target,onClick,btnInfo) {self.submitPop()} /**点击后事件回调**/
      	}
		let footerContent = <div className='rec-pop-footer'>
								<span className='rec-cancleBtn'><BaseButton {...btnOpt1} /></span>
								<span className='rec-submitBtn'><BaseButton {...btnOpt2} /></span>
							</div>

		let inputOption = {
			maxCount: maxCount
			,canCreate: canCreate
			,createBtnText: createBtnText
			,disableKeyDown: disableKeyDown //是否禁用回车添加项功能
			,disableInput: disableInput
			,defaultItems: this.state.defaultItems
			,title: title //label文本
			,isRequired: isRequired
			,lablePos: lablePos //label位置，true时在左边，false在上边
            ,lableText: lableText //label中文字对齐方式，true左对齐，false右对齐 
			,errorStatus: errorStatus
			,errorMessage: errorMessage
			,isDropList: true
			,onClick: function(event, status, value) {
				self.handleClick(event, value)
			}
			,onFocus: function(event, status, value) {}
			,onChange: function(event, status, value) {
				onSearch(event, event.target.value)
			}
			,onBlur: function(event, status, value) {}
			,addItemCallBack: function(event, status, value) {}
			,deleteItemCallBack: function(event, status, value) {
				self.handleDelete(event, value)
			}
			,createNewItem: function() {
				self.createUserItem()
			}
		}
		let popOption = {
		    popShow: this.state.popShow
		    ,title: "新建" //头部名称
		    ,hasHeader: true //是否显示头部
		    ,hasFooter: true //是否显示底部，含有确定取消按钮
		    ,dataType: "component" //string 字符串 component 组件
		    ,data: "" //需要传入引入组件的数据
		    ,hasRender: true // 传入的组件是否已渲染，只有当dateType为component时有效
		    ,animation: true //是否用弹窗的动效
		    ,dragDisabled:false //是否可以拖拽弹窗，默认true为禁止拖拽，false为未禁用拖拽
		    ,contentResizeListener: true //开启监听弹层内容高度变化
		    ,footerContent: footerContent
		    // ,headerContent: <div></div> //自定义渲染头部
		    ,customStyle: {'zIndex': '100000','maxHeight':'300px'}
		    ,bodyMask: true
		    ,subBtnShow: false //默认为true
		    ,cloBtnShow: false //默认为true
		    ,showMask: true //默认为false
		    ,isLookUpV2: true  //平台专用
		    ,fixPos: true //专门解决在win10 IE下非iframe页面下弹窗错位问题
		    ,preSubmit: () => {} // 点击确定按钮前会调用的方法，非必须
		    ,preCancel: () => {} //点击取消按钮前调用的方法，非必须
		} 
		
		let DemoComponent = <CreatePage ref='createPage' isEmailError={isEmailError} emailErrorTip={emailErrorTip || ''} validateEmail={validateEmail} />;
		let CommonPopCmp = this.state.popShow ? <CommonPop {...popOption} PopComponent = {DemoComponent} closePop={this.closePop} /> : null; 

    	return (
    		<div>
				<TagInput ref='tagInput' {...inputOption} />
    			{CommonPopCmp}
    		</div>
  		)
  	}
}
